@@ -11,19 +11,25 @@
 
 use strict;
 use warnings;
+# this test apparently isn't smart enough to tell difference between object
+#    attribute access and real hash-refs:
+## no critic (ProhibitAccessOfPrivateData)
 use Readonly;
 use DBI;
 use Carp;
 use IO::File;
 
 use Getopt::Long;
-use Games::Go::AGA::BayRate::Collection;
 use Math::GSL::Errno ( ':all' ); # for various constants like $GSL_SUCCESS
-use Math::GSL::Vector;
-use Math::GSL::Multimin ( ':all' ); # for &main::gsl_multimin_fdfminimizer_minimum
-use Math::GSL::BLAS ( ':all' );   # for gsl_blas_dnrm2
+use Math::GSL::Multimin ( 'gsl_multimin_fdfminimizer_minimum' );
+use Math::GSL::BLAS ( 'gsl_blas_dnrm2' );
+use Games::Go::AGA::BayRate::GSL::Multimin qw(
+    raw_gsl_multimin_fminimizer_fval
+    raw_gsl_multimin_fdfminimizer_gradient
+);
+use Games::Go::AGA::BayRate::Collection;
 
-our $VERSION = '0.084'; # VERSION
+our $VERSION = '0.102'; # VERSION
 
 # # column offset in games table
 # Readonly my $Game_ID              => 0 ;
@@ -401,7 +407,7 @@ sub iter_hook {
     if (ref $state eq 'Math::GSL::Multimin::gsl_multimin_fminimizer') {
         my $f = # gsl_multimin_fminimizer_fval($state),    # hmm, struct member, not a function
                 # ok, do it this way instead:
-            Games::Go::AGA::BayRate::GSL::Multimin::my_fminimizer_fval($state),
+            raw_gsl_multimin_fminimizer_fval($state),
         my $size = gsl_multimin_fminimizer_size($state);
         printf("F Iteration %d\tf() = %g\tsimplex size = %g\n", $iter, $f, $size);
         if ($status == $GSL_SUCCESS) {
@@ -409,7 +415,7 @@ sub iter_hook {
         }
     }
     elsif (ref $state eq 'Math::GSL::Multimin::gsl_multimin_fdfminimizer') {
-        my $gradient = Games::Go::AGA::BayRate::GSL::Multimin::my_fdfminimizer_gradient($state);
+        my $gradient = raw_gsl_multimin_fdfminimizer_gradient($state);
         my $minimum = gsl_multimin_fdfminimizer_minimum($state);
         printf("FDF Iteration %d\tf() = %g\tnorm = %g\tStatus = %d\n",
             $iter,
