@@ -30,6 +30,9 @@
 use 5.008;
 use strict;
 use warnings;
+# this test apparently isn't smart enough to tell difference between object
+#    attribute access and real hash-refs:
+## no critic (ProhibitAccessOfPrivateData)
 
 package Games::Go::AGA::BayRate::Collection;
 
@@ -44,14 +47,33 @@ use Games::Go::AGA::BayRate::Game;
 use Math::GSL::Permutation ( ':all' );
 use Math::GSL::Matrix ( ':all' );
 use Math::GSL::Vector ( ':all' );
-use Math::GSL::Errno ( ':all' ); # for various constants like $GSL_CONTINUE
+use Math::GSL::Errno
+    qw(
+        $GSL_SUCCESS
+        $GSL_CONTINUE
+    );
 use Math::GSL::Const ( ':all' ); # for various constants like $M_PI
-use Math::GSL::Multimin ( ':all' ); # for f(df)minimizer functions
+use Math::GSL::Multimin          # for f(df)minimizer functions
+    qw(
+        $gsl_multimin_fdfminimizer_vector_bfgs2
+        $gsl_multimin_fminimizer_nmsimplex
+        gsl_multimin_fminimizer_iterate
+        gsl_multimin_fminimizer_x
+        gsl_multimin_fdfminimizer_iterate
+        gsl_multimin_fdfminimizer_x
+        gsl_multimin_test_size
+        gsl_multimin_test_gradient
+    );
 use Math::GSL::SF ( ':all' );   # Special Functions (for sf_erfc)
 use Math::GSL::Linalg ( ':all' );   # Linear Algebra (for gsl_linalg_LU_decomp)
-use Games::Go::AGA::BayRate::GSL::Multimin;
+use Games::Go::AGA::BayRate::GSL::Multimin qw(
+    raw_gsl_vector_size
+    my_gsl_multimin_fminimizer_set
+    my_gsl_multimin_fdfminimizer_set
+    raw_gsl_multimin_fdfminimizer_gradient
+);
 
-our $VERSION = '0.084'; # VERSION
+our $VERSION = '0.102'; # VERSION
 
 # Set some constants
 #Readonly our $M_SQRT2             => sqrt(2.0);
@@ -88,15 +110,16 @@ sub DEBUG_gsl_matrix_get {
 }
 
 sub print_vector {
-    my ($raw_v, $count) = @_;
+    my ($v, $count) = @_;
 
+    $v = $v->raw if (not ref $v =~ 'Math::GSL::.*::gsl_vector');
     if (not $count or $count <= 0) {
-        $count = Games::Go::AGA::BayRate::GSL::Multimin::my_vector_size($raw_v);    # what a hack!
+        $count = raw_gsl_vector_size($v);
     }
     my $ii;
     for ($ii = 0; $ii < $count; $ii ++) {
         if ($ii % 10 == 0) { printf("%3d:", $ii); }
-        printf(" % .24g", gsl_vector_get($raw_v, $ii));
+        printf(" % .24g", gsl_vector_get($v, $ii));
         if ($ii % 10 == 9) { print("\n"); }
     }
     if ($ii % 10 != 0) { print("\n"); }
@@ -697,7 +720,7 @@ sub calc_ratings_f {
     gsl_vector_set_all($raw_ss, 2);
 
     # minimizer 'state'
-    my $state = Games::Go::AGA::BayRate::GSL::Multimin::my_fminimizer_set (
+    my $state = my_gsl_multimin_fminimizer_set(
         $gsl_multimin_fminimizer_nmsimplex,    # type
         # gsl_multimin_function_f structure members:
             \&my_f,    # f       function
@@ -787,9 +810,9 @@ sub calc_ratings_fdf {
     my %seeds;
     foreach my $player (@{$self->{players_array}}) {
         my $seed = $player->get_cseed;
-# TODO  while (exists $seeds{$seed}) {
-#           $seed = $player->get_cseed + rand(0.001);
-#       }
+        while (exists $seeds{$seed}) {
+            $seed = $player->get_cseed + rand(0.001);
+        }
 
         $seeds{$seed} = 1;
         # $x->set($player->get_index, $player->get_cseed + gsl_ran_flat(r, 0, 0.1));
@@ -797,7 +820,7 @@ sub calc_ratings_fdf {
     }
 
     # minimizer 'state'
-    my $state = Games::Go::AGA::BayRate::GSL::Multimin::my_fdfminimizer_set (
+    my $state = my_gsl_multimin_fdfminimizer_set(
         $gsl_multimin_fdfminimizer_vector_bfgs2,    # type
         # gsl_multimin_function_fdf structure members:
             \&my_f,    # f       function
@@ -823,7 +846,7 @@ sub calc_ratings_fdf {
 
         last if ($status != $GSL_CONTINUE);
 
-        my $gradient = Games::Go::AGA::BayRate::GSL::Multimin::my_fdfminimizer_gradient($state);
+        my $gradient = raw_gsl_multimin_fdfminimizer_gradient($state);
         $status = gsl_multimin_test_gradient($gradient, $gradient_spec);
         if ($self->{iter_hook}) {
             &{$self->{iter_hook}}($self, $state, $iter, $status);     # call user iteration hook
