@@ -39,7 +39,7 @@ use Math::GSL::Errno ( ':all' );
 use Math::GSL::Spline ( ':all' );
 use Math::GSL::Interp ( ':all' );
 
-our $VERSION = '0.084'; # VERSION
+our $VERSION = '0.102'; # VERSION
 
 my $spline;     # spline is class data
 
@@ -86,23 +86,12 @@ sub new {
     return($self);
 }
 
-# make read and write accessor methods
-foreach my $name ( qw(
-            sigma
-            id
-            index
-        )) {
-    no strict 'refs'; ## no critic
-    # setter
-    *{"set_$name"} = sub {
-        $_[0]->{$name} = $_[1];
-        return shift->{$name};
-    };
-    # getter
-    *{"get_$name"} = sub {
-        return shift->{$name};
-    };
-}
+sub set_sigma { return $_[0]->{sigma} = $_[1] };
+sub get_sigma { return $_[0]->{sigma} };
+sub set_id    { return $_[0]->{id}    = $_[1] };
+sub get_id    { return $_[0]->{id}    };
+sub set_index { return $_[0]->{index} = $_[1] };
+sub get_index { return $_[0]->{index} };
 
 sub set_seed {
     my ($self, $new) = @_;
